@@ -16,33 +16,34 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.secretmanager_v1.services.secret_manager_service import pagers
-from google.cloud.secretmanager_v1.types import resources
-from google.cloud.secretmanager_v1.types import service
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import SecretManagerServiceTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.secretmanager_v1.services.secret_manager_service import pagers
+from google.cloud.secretmanager_v1.types import resources, service
+
+from .transports.base import DEFAULT_CLIENT_INFO, SecretManagerServiceTransport
 from .transports.grpc import SecretManagerServiceGrpcTransport
 from .transports.grpc_asyncio import SecretManagerServiceGrpcAsyncIOTransport
 
@@ -598,7 +599,6 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         containing no
         [SecretVersions][google.cloud.secretmanager.v1.SecretVersion].
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
@@ -728,7 +728,6 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         containing secret data and attaches it to an existing
         [Secret][google.cloud.secretmanager.v1.Secret].
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
@@ -837,7 +836,6 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         r"""Gets metadata for a given
         [Secret][google.cloud.secretmanager.v1.Secret].
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
@@ -941,7 +939,6 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         r"""Updates metadata of an existing
         [Secret][google.cloud.secretmanager.v1.Secret].
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
@@ -1138,7 +1135,6 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         [SecretVersions][google.cloud.secretmanager.v1.SecretVersion].
         This call does not return secret data.
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
@@ -1255,7 +1251,6 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         recently created
         [SecretVersion][google.cloud.secretmanager.v1.SecretVersion].
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
@@ -1362,7 +1357,6 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         recently created
         [SecretVersion][google.cloud.secretmanager.v1.SecretVersion].
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
@@ -1470,7 +1464,6 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         to
         [DISABLED][google.cloud.secretmanager.v1.SecretVersion.State.DISABLED].
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
@@ -1575,7 +1568,6 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         to
         [ENABLED][google.cloud.secretmanager.v1.SecretVersion.State.ENABLED].
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
@@ -1681,7 +1673,6 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         [DESTROYED][google.cloud.secretmanager.v1.SecretVersion.State.DESTROYED]
         and irrevocably destroys the secret data.
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
@@ -1784,17 +1775,17 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         are enforced according to the policy set on the associated
         [Secret][google.cloud.secretmanager.v1.Secret].
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
+            from google.iam.v1 import iam_policy_pb2  # type: ignore
 
             def sample_set_iam_policy():
                 # Create a client
                 client = secretmanager_v1.SecretManagerServiceClient()
 
                 # Initialize request argument(s)
-                request = secretmanager_v1.SetIamPolicyRequest(
+                request = iam_policy_pb2.SetIamPolicyRequest(
                     resource="resource_value",
                 )
 
@@ -1816,21 +1807,26 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
 
         Returns:
             google.iam.v1.policy_pb2.Policy:
-                Defines an Identity and Access Management (IAM) policy. It is used to
-                   specify access control policies for Cloud Platform
-                   resources.
+                An Identity and Access Management (IAM) policy, which specifies access
+                   controls for Google Cloud resources.
 
                    A Policy is a collection of bindings. A binding binds
-                   one or more members to a single role. Members can be
-                   user accounts, service accounts, Google groups, and
-                   domains (such as G Suite). A role is a named list of
-                   permissions (defined by IAM or configured by users).
-                   A binding can optionally specify a condition, which
-                   is a logic expression that further constrains the
-                   role binding based on attributes about the request
-                   and/or target resource.
+                   one or more members, or principals, to a single role.
+                   Principals can be user accounts, service accounts,
+                   Google groups, and domains (such as G Suite). A role
+                   is a named list of permissions; each role can be an
+                   IAM predefined role or a user-created custom role.
 
-                   **JSON Example**
+                   For some types of Google Cloud resources, a binding
+                   can also specify a condition, which is a logical
+                   expression that allows access to a resource only if
+                   the expression evaluates to true. A condition can add
+                   constraints based on attributes of the request, the
+                   resource, or both. To learn which resources support
+                   conditions in their IAM policies, see the [IAM
+                   documentation](\ https://cloud.google.com/iam/help/conditions/resource-policies).
+
+                   **JSON example:**
 
                       {
                          "bindings": [
@@ -1845,17 +1841,17 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
 
                             }, { "role":
                             "roles/resourcemanager.organizationViewer",
-                            "members": ["user:eve@example.com"],
+                            "members": [ "user:eve@example.com" ],
                             "condition": { "title": "expirable access",
                             "description": "Does not grant access after
                             Sep 2020", "expression": "request.time <
                             timestamp('2020-10-01T00:00:00.000Z')", } }
 
-                         ]
+                         ], "etag": "BwWWja0YfJA=", "version": 3
 
                       }
 
-                   **YAML Example**
+                   **YAML example:**
 
                       bindings: - members: - user:\ mike@example.com -
                       group:\ admins@example.com - domain:google.com -
@@ -1866,11 +1862,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
                       condition: title: expirable access description:
                       Does not grant access after Sep 2020 expression:
                       request.time <
-                      timestamp('2020-10-01T00:00:00.000Z')
+                      timestamp('2020-10-01T00:00:00.000Z') etag:
+                      BwWWja0YfJA= version: 3
 
                    For a description of IAM and its features, see the
-                   [IAM developer's
-                   guide](\ https://cloud.google.com/iam/docs).
+                   [IAM
+                   documentation](\ https://cloud.google.com/iam/docs/).
 
         """
         # Create or coerce a protobuf request object.
@@ -1915,17 +1912,17 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         Returns empty policy if the secret exists and does not
         have a policy set.
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
+            from google.iam.v1 import iam_policy_pb2  # type: ignore
 
             def sample_get_iam_policy():
                 # Create a client
                 client = secretmanager_v1.SecretManagerServiceClient()
 
                 # Initialize request argument(s)
-                request = secretmanager_v1.GetIamPolicyRequest(
+                request = iam_policy_pb2.GetIamPolicyRequest(
                     resource="resource_value",
                 )
 
@@ -1947,21 +1944,26 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
 
         Returns:
             google.iam.v1.policy_pb2.Policy:
-                Defines an Identity and Access Management (IAM) policy. It is used to
-                   specify access control policies for Cloud Platform
-                   resources.
+                An Identity and Access Management (IAM) policy, which specifies access
+                   controls for Google Cloud resources.
 
                    A Policy is a collection of bindings. A binding binds
-                   one or more members to a single role. Members can be
-                   user accounts, service accounts, Google groups, and
-                   domains (such as G Suite). A role is a named list of
-                   permissions (defined by IAM or configured by users).
-                   A binding can optionally specify a condition, which
-                   is a logic expression that further constrains the
-                   role binding based on attributes about the request
-                   and/or target resource.
+                   one or more members, or principals, to a single role.
+                   Principals can be user accounts, service accounts,
+                   Google groups, and domains (such as G Suite). A role
+                   is a named list of permissions; each role can be an
+                   IAM predefined role or a user-created custom role.
 
-                   **JSON Example**
+                   For some types of Google Cloud resources, a binding
+                   can also specify a condition, which is a logical
+                   expression that allows access to a resource only if
+                   the expression evaluates to true. A condition can add
+                   constraints based on attributes of the request, the
+                   resource, or both. To learn which resources support
+                   conditions in their IAM policies, see the [IAM
+                   documentation](\ https://cloud.google.com/iam/help/conditions/resource-policies).
+
+                   **JSON example:**
 
                       {
                          "bindings": [
@@ -1976,17 +1978,17 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
 
                             }, { "role":
                             "roles/resourcemanager.organizationViewer",
-                            "members": ["user:eve@example.com"],
+                            "members": [ "user:eve@example.com" ],
                             "condition": { "title": "expirable access",
                             "description": "Does not grant access after
                             Sep 2020", "expression": "request.time <
                             timestamp('2020-10-01T00:00:00.000Z')", } }
 
-                         ]
+                         ], "etag": "BwWWja0YfJA=", "version": 3
 
                       }
 
-                   **YAML Example**
+                   **YAML example:**
 
                       bindings: - members: - user:\ mike@example.com -
                       group:\ admins@example.com - domain:google.com -
@@ -1997,11 +1999,12 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
                       condition: title: expirable access description:
                       Does not grant access after Sep 2020 expression:
                       request.time <
-                      timestamp('2020-10-01T00:00:00.000Z')
+                      timestamp('2020-10-01T00:00:00.000Z') etag:
+                      BwWWja0YfJA= version: 3
 
                    For a description of IAM and its features, see the
-                   [IAM developer's
-                   guide](\ https://cloud.google.com/iam/docs).
+                   [IAM
+                   documentation](\ https://cloud.google.com/iam/docs/).
 
         """
         # Create or coerce a protobuf request object.
@@ -2051,17 +2054,17 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         authorization checking. This operation may "fail open" without
         warning.
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
+            from google.iam.v1 import iam_policy_pb2  # type: ignore
 
             def sample_test_iam_permissions():
                 # Create a client
                 client = secretmanager_v1.SecretManagerServiceClient()
 
                 # Initialize request argument(s)
-                request = secretmanager_v1.TestIamPermissionsRequest(
+                request = iam_policy_pb2.TestIamPermissionsRequest(
                     resource="resource_value",
                     permissions=['permissions_value_1', 'permissions_value_2'],
                 )
